@@ -622,6 +622,9 @@ struct IndexTarget
 class pkgAcqMetaSig : public pkgAcquire::Item
 {
    protected:
+   /** \brief The last good signature file */
+   string LastGoodSig;
+
    /** \brief The fetch request that is currently being processed. */
    pkgAcquire::ItemDesc Desc;
 
